package net.javajigi.petstore.action;

import java.util.ResourceBundle;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import net.javajigi.petstore.model.Cart;
import net.javajigi.petstore.model.PetStore;
import net.javajigi.petstore.model.PetStoreImpl;
import net.javajigi.petstore.model.domain.Customer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

public abstract class BaseAction extends Action {
	public static final String BUNDLE_NAME = "Resources";
	public static final String CART_KEY = "cart";
	public static final String ERROR = "error";
	public static final String MESSAGE_KEY = "message";
	public static final String SUCCESS = "success";
	public static final String USERID_KEY = "userId";
	public static final String USERNAME_KEY = "username";

	protected Log _log = LogFactory.getLog(getClass());

	protected void clearSession(HttpServletRequest request) throws Exception {
		HttpSession session = request.getSession();

		session.removeAttribute(USERID_KEY);
		session.removeAttribute(USERNAME_KEY);

		Cart cart = getCart(false, request);

		if (cart != null) {
			session.removeAttribute(CART_KEY);
		}
	}

	protected abstract ActionForward doExecute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
		throws Exception;

	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
		throws Exception {
		_log.info("execute()");

		return doExecute(mapping, form, request, response);
	}

	public Cart getCart(boolean create, HttpServletRequest request)
		throws Exception {
		HttpSession session = request.getSession();
		Cart cart = (Cart) session.getAttribute(CART_KEY);
		if ((cart == null) && create) {
			cart = new Cart();
			session.setAttribute(CART_KEY, cart);
		}

		return cart;
	}

	public Cart getCart(HttpServletRequest request) throws Exception {
		return getCart(true, request);
	}

	public PetStore getPetstore() throws Exception {
		return PetStoreImpl.instance();
	}

	public String getString(String key) {
		try {
			return ResourceBundle.getBundle(BUNDLE_NAME).getString(key);
		} catch (Exception e) {
			return "???" + key + "???";
		}
	}

	protected void initSession(Customer customer, HttpServletRequest request) {
		HttpSession session = request.getSession();
		session.setAttribute(USERID_KEY, customer.getUserId());
		session.setAttribute(USERNAME_KEY, customer.getName());
	}
}
