package net.javajigi.petstore.model.domain;

import java.io.Serializable;

/**
 * @hibernate.class
 *         table="T_CUSTOMER"
 */
public class Customer implements Serializable {
	private Account _account = new Account();
	private Address _address = new Address();
	private CreditCard _creditCard = new CreditCard();
	private String _name = "";
	private String _email = "";
	private String _phoneNo = "";
	
	private Order order;

	public Customer() {
	}

	public Customer(Account account) {
		_account = account;
	}
	/**
	 * @return Account
	 *
	 * @hibernate.one-to-one
	 *         cascade="all"
	 */
	public Account getAccount() {
		return _account;
	}

	/**
	 * @return Address
	 *
	 * @hibernate.component
	 */
	public Address getAddress() {
		return _address;
	}

	/**
	 * @return CreditCard
	 *
	 * @hibernate.component
	 */
	public CreditCard getCreditCard() {
		return _creditCard;
	}

	/**
	 * @return String
	 *
	 * @hibernate.id
	 *        generator-class="assigned"
	 *         length="10"
	 */
	public String getUserId() {
		return (_account != null) ? _account.getUserId() : "";
	}

	/**
	 * @return String
	 *
	 * @hibernate.property
	 *         length="255"
	 *         not-null="true"
	 */
	public String getEmail() {
		return _email;
	}

	/**
	 * @return String
	 *
	 * @hibernate.property
	 *      length="20"
	 */
	public String getName() {
		return _name;
	}

	/**
	 * @return String
	 *
	 * @hibernate.property
	 *      length="15"
	 */
	public String getPhoneNo() {
		return _phoneNo;
	}

	public void set(Customer cst) {
		_account.set(cst.getAccount());
		_address.set(cst.getAddress());
		_creditCard.set(cst.getCreditCard());
		_email = cst.getEmail();
		_name = cst.getName();
		_phoneNo = cst.getPhoneNo();
	}

	/**
	 * Sets the account.
	 * @param account The account to set
	 */
	public void setAccount(Account account) {
		_account = account;
	}

	/**
	 * Sets the address.
	 * @param address The address to set
	 */
	public void setAddress(Address address) {
		_address = address;
	}

	/**
	 * Sets the creditCard.
	 * @param creditCard The creditCard to set
	 */
	public void setCreditCard(CreditCard creditCard) {
		_creditCard = creditCard;
	}

	/**
	 * Sets the userId.
	 * @param userId The userId to set
	 */
	public void setUserId(String userId) {
		if (_account == null) {
			_account = new Account();
		}

		_account.setUserId(userId);
	}

	public void setEmail(String email) {
		_email = email;
	}

	public void setname(String name) {
		_name = name;
	}

	public void setPhoneNo(String phoneNo) {
		_phoneNo = phoneNo;
	}
	public Order getOrder() {
		return order;
	}

	public void setOrder(Order order) {
		this.order = order;
	}

}
