package net.sf.hibernate.examples.quickstart;

import net.sf.hibernate.*;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.ServletException;

import edu.arbor.util.plugin.HibernatePlugIn;

import java.util.*;
import java.io.IOException;
import java.io.PrintWriter;

public class TestServlet extends HttpServlet {

	//private SessionFactory sessionFactory;
	private Session session;
	private Transaction transaction;

	public void doGet(HttpServletRequest request, HttpServletResponse response)
		throws ServletException, IOException {

		try {
			// Initialize Hibernate (Configuration and SessionFactory)
			//initHibernate();

			// Prepare out
			response.setContentType("text/html");
			PrintWriter out = response.getWriter();

			// Create some Cats
			beginTransaction();
			createCats(out);
			endTransaction(true);

			// Select all Cats
			beginTransaction();
			selectAllCats(out);
			endTransaction(false);

			// Select female Cats
			beginTransaction();
			selectFemaleCats(out);
			endTransaction(false);

		} catch (HibernateException e) {
			throw new ServletException(e);
		}

	}

	public void createCats(PrintWriter out) throws HibernateException {

		out.print("<h3>Creating Cats:</h3>");
		out.println("CREATING 'Princess'...<br/>");
		Cat princess = new Cat();
		princess.setName("Princess");
		princess.setSex('F');
		princess.setWeight(7.4f);
		session.save(princess);

		out.println("CREATING 'Max'...<br/>");
		Cat max = new Cat();
		max.setName("Max");
		max.setSex('M');
		max.setWeight(8.1f);
		session.save(max);
	}

	public void selectAllCats(PrintWriter out) throws HibernateException {

		out.print("<h3>Retrieving all Cats:</h3>");
		String queryString = "select cat from Cat as cat";
		Query query = session.createQuery(queryString);
		for (Iterator it = query.iterate(); it.hasNext();) {
			Cat cat = (Cat) it.next();
			out.println(
				"CAT: "
					+ cat.getName()
					+ " ("
					+ cat.getSex()
					+ ", "
					+ cat.getWeight()
					+ ")<br/>");
		}
	}

	public void selectFemaleCats(PrintWriter out) throws HibernateException {

		out.print("<h3>Retrieving female Cats:</h3>");
		String queryString = "select cat from Cat as cat where cat.sex = :sex";
		Query query = session.createQuery(queryString);
		query.setCharacter("sex", 'F');
		for (Iterator it = query.iterate(); it.hasNext();) {
			Cat cat = (Cat) it.next();
			out.println(
				"CAT: "
					+ cat.getName()
					+ " ("
					+ cat.getSex()
					+ ", "
					+ cat.getWeight()
					+ ")<br/>");
		}
	}

	// Helper Methods
	private void initHibernate() throws HibernateException {

		// Load Configuration and build SessionFactory
		//sessionFactory = new Configuration().configure().buildSessionFactory();
	}

	private void beginTransaction() throws HibernateException {
		session =
			((SessionFactory) getServletContext()
				.getAttribute(HibernatePlugIn.SESSION_FACTORY_KEY))
				.openSession();
		transaction = session.beginTransaction();
	}

	private void endTransaction(boolean commit) throws HibernateException {

		if (commit) {
			transaction.commit();
		} else {
			// Don't commit the transaction, can be faster for read-only operations
			transaction.rollback();
		}
		session.close();
	}
}
